==> nomachine-8.2.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/NXNodeHostKeyVerificationFailed.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::NXNodeHostKeyVerificationFailed::BEGIN{package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::NXNodeHostKeyVerificationFailed::BEGIN{package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::NXNodeHostKeyVerificationFailed::notify{package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;(my $self=shift (@_));
NXMsg::register_error ((""),
"\x65\x4b\x65\x79\x56\x65\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x46\x61\x69\x6c\x65\x64"
,(0x0fd1+ 2431-0x171a));NXMsg::error (
"\x65\x4b\x65\x79\x56\x65\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x46\x61\x69\x6c\x65\x64"
,"\x67\x65\x6e\x65\x72\x61\x6c");}package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.3.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/NXNodeHostKeyVerificationFailed.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::NXNodeHostKeyVerificationFailed::BEGIN{package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::NXNodeHostKeyVerificationFailed::BEGIN{package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::NXNodeHostKeyVerificationFailed::notify{package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;(my $self=shift (@_));
NXMsg::register_error ((""),
"\x65\x4b\x65\x79\x56\x65\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x46\x61\x69\x6c\x65\x64"
,(0x033a+ 7615-0x1ec3));NXMsg::error (
"\x65\x4b\x65\x79\x56\x65\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x46\x61\x69\x6c\x65\x64"
,"\x67\x65\x6e\x65\x72\x61\x6c");}package 
Exception::NXNodeHostKeyVerificationFailed;no warnings;"\x3f\x3f\x3f";
